#!/usr/bin/env python
# -*- mode: landisk-python; coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta

"""FAL command for handling event"""

from ionas.request import Entry
from iobase.xmldata import XmlConfNode
from iobase.exception import ExecError
import libevh.evhcmd as evhcmd
import fal_info
from product_conf.reqinfo import Results, ReqTypes


class EvhFtpHostNameUpdate(evhcmd.EvhCmd):
    """Event Handler command implementation class."""

    #
    # Utility method
    #

    def __send_request(self, fal, type, node=None):

        res_entry = self.send_entry(Entry(type, node), fal)

        if res_entry.get_result() != Results.OK:
            raise ExecError(fal)

        return res_entry

    def __restart_service(self):

        XML = """<servicectrl>
            <servicelist>
                <service><name>proftpd</name></service>
            </servicelist>
        </servicectrl>"""

        self.__send_request(fal_info.FAL_SERVICECTRL_PATH,
            ReqTypes.SUSPEND, XmlConfNode(XML))
        self.__send_request(fal_info.FAL_SERVICECTRL_PATH,
            ReqTypes.RESUME, XmlConfNode(XML))

    #
    # Request handlers
    #

    def __event_handler(self, entry):
        """Handle "event" request."""

        sysinfo_node = self.__send_request(fal_info.FAL_SYSINFO_PATH,
            ReqTypes.LOAD).get()

        self.__send_request(fal_info.FAL_FTP_PATH,
            ReqTypes.APPLY, sysinfo_node)

        self.__restart_service()

        entry.set_result(Results.OK)
        return entry

    def __init__(self):
        """Constructor."""

        evhcmd.EvhCmd.__init__(self, evhcmd.EvhCmdOption())

        self.set_handler(ReqTypes.EVENT, self.__event_handler)

#
# Main
#

if __name__ == "__main__":
    EvhFtpHostNameUpdate().handle_request()
